@@ -36,7 +36,7 @@ class InstaLog:
             if type(val) == expected_type:
                 return
         raise Exception(
-            'InstaLog: given {} of type {} expected one of [{}]'.format(
+            'InstaLog: given {} of type {} expected one of {}'.format(
                 name,
                 type(val),
                 expected_types
@@ -99,9 +99,7 @@ class InstaLog:
             "remote_ip": request.remote_addr,
             "protocol": request.environ.get('SERVER_PROTOCOL'),
             "method": request.method.upper(),
-            "path": request.path,
-            "full_path": request.full_path,
-            "url": request.url,
+            "path": '{}{}'.format(request.root_path, request.path),
             "query_params": request.args,
             "error_type": type(exception).__name__,
             "error_message": str(exception)
